﻿using PIbd_24_EredavkinRA_BusBusiness.Entities;
using PIbd_24_EredavkinRA_BusBusiness.Repositories;
using PIbd_24_EredavkinRA_BusBusiness.Repositories.Implementations;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace PIbd_24_EredavkinRA_BusBusiness.Forms;

public partial class FormBus : Form
{
    private readonly IBusRepository _busRepository;
    private int? _busId;
    public int Id
    {
        set
        {
            try
            {
                var bus = _busRepository.ReadBusByID(value);
                if (bus == null)
                {
                    throw new InvalidDataException(nameof(bus));
                }
                comboBoxBus.Text = bus.Model;
                textBoxNZ.Text = bus.N_Z;
                Mileage.Value = bus.Bus_mileage;
                numericUpDownCapacity.Value = bus.Capacity;
                _busId = bus.Id;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;

            }
        }

    }
    public FormBus(IBusRepository busRepository)
    {
        InitializeComponent();
        _busRepository = busRepository ??
            throw new ArgumentNullException(nameof(busRepository));
    }

    private void buttonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(comboBoxBus.Text) ||string.IsNullOrWhiteSpace(textBoxNZ.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }
            if (_busId.HasValue)
            {
                _busRepository.UpdateBus(CreateBus(_busId.Value));
            }
            else
            {
                _busRepository.CreateBus(CreateBus(0));
            }
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void buttonleave_Click(object sender, EventArgs e) => Close();

    private Bus CreateBus(int id) => Bus.CreateEntity(id,
                                                      comboBoxBus.Text,
                                                      textBoxNZ.Text,
                                                      Convert.ToInt32(Mileage.Value),
                                                      Convert.ToInt32(numericUpDownCapacity.Value));

    
}
