﻿using PIbd_24_EredavkinRA_BusBusiness.Entities;
using PIbd_24_EredavkinRA_BusBusiness.Entities.Enums;
using PIbd_24_EredavkinRA_BusBusiness.Repositories;
using PIbd_24_EredavkinRA_BusBusiness.Repositories.Implementations;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.VisualStyles.VisualStyleElement;

namespace PIbd_24_EredavkinRA_BusBusiness.Forms;

public partial class FormRout : Form
{
    private readonly IRoutRepositories _routRepository;
    private int? _routId;
    public int Id
    {
        set
        {
            try
            {
                var rout = _routRepository.ReadRoutByID(value);
                if (rout == null)
                {
                    throw new
                    InvalidDataException(nameof(rout));
                }
                textBoxStarPoint.Text = rout.StartStop;
                textBoxEndPoint.Text = rout.EndStop;
                numericUpDownNumber.Value = rout.NumberRout;
                _routId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }
    public FormRout(IRoutRepositories routRepositories)
    {
        InitializeComponent();
        _routRepository = routRepositories ??
            throw new ArgumentNullException(nameof(routRepositories));

    }

    private void buttonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxStarPoint.Text) || string.IsNullOrWhiteSpace(textBoxEndPoint.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }
            if (_routId.HasValue)
            {
                _routRepository.UpdateRout(CreateRout(_routId.Value));
            }
            else
            {
                _routRepository.CreateRout(CreateRout(0));
            }
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void buttonLoad_Click(object sender, EventArgs e) => Close();

    private Rout CreateRout(int id) => Rout.CreateEntity(id, 
                                                       textBoxStarPoint.Text, 
                                                       textBoxEndPoint.Text, 
                                                       Convert.ToInt32(numericUpDownNumber.Value));
    

    
}






