﻿using PIbd_24_EredavkinRA_BusBusiness.Entities;
using PIbd_24_EredavkinRA_BusBusiness.Entities.Enums;
using PIbd_24_EredavkinRA_BusBusiness.Repositories;


namespace PIbd_24_EredavkinRA_BusBusiness.Forms;

public partial class FormStaff : Form
{
    private readonly IStaffRepositories _staffRepository;
    private int? _staffId;
    public int Id
    {
        set
        {
            try
            {
                var staff = _staffRepository.ReadStaffByID(value);
                if (staff == null)
                {
                    throw new
                    InvalidDataException(nameof(staff));
                }
                foreach (EmployeePost elem in Enum.GetValues(typeof(EmployeePost)))
                {
                    if ((elem & staff.EmployeePost) != 0)
                    {
                        checkedListBoxStaff.SetItemChecked(checkedListBoxStaff.Items.IndexOf(elem), true);
                    }
                }
                textBoxFirstName.Text = staff.FirstName;
                textBoxLastName.Text = staff.LastName;
                
                _staffId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }


    public FormStaff(IStaffRepositories staffRepositories)
    {
        InitializeComponent();
        _staffRepository = staffRepositories ??
            throw new ArgumentNullException(nameof(staffRepositories));
        foreach (var elem in Enum.GetValues(typeof(EmployeePost)))
        {
            checkedListBoxStaff.Items.Add(elem);
        }
    }

    private void buttoтSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxFirstName.Text) ||string.IsNullOrWhiteSpace(textBoxLastName.Text) || checkedListBoxStaff.CheckedItems.Count == 1)
            {
                throw new Exception("Имеются незаполненныеполя");
            }
            if (_staffId.HasValue)
            {
                _staffRepository.UpdateStaff(CreateStaff(_staffId.Value));
            }
            else
            {
                _staffRepository.CreateStaff(CreateStaff(0));
            }
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void buttonCancel_Click(object sender, EventArgs e) => Close();
    private Staff CreateStaff(int id)
    {
        EmployeePost employeePost = EmployeePost.None;
        foreach (var elem in checkedListBoxStaff.CheckedItems)
        {
            employeePost |= (EmployeePost)elem;
        }
        return Staff.CreatEntity(id, textBoxFirstName.Text, textBoxLastName.Text, employeePost);
    }




}
